PeerInfo

Enum PeerInfo 

pub enum PeerInfo {
    User {
        id: i64,
        auth: Option<PeerAuth>,
        bot: Option<bool>,
        is_self: Option<bool>,
    },
    Chat {
        id: i64,
    },
    Channel {
        id: i64,
        auth: Option<PeerAuth>,
        kind: Option<ChannelKind>,
    },
}
An exploded peer reference along with any known useful information about the peer.

Variants



User

Fields

id: i64

Bare user identifier.

Despite being i64, Telegram only uses strictly positive values.

auth: Option<PeerAuth>

Non-ambient authority bound to both the user itself and the session.

bot: Option<bool>

Whether this user represents a bot or not.

is_self: Option<bool>

Whether this user represents the logged-in user authorized by this session or not.



Chat

Fields

id: i64

Bare chat identifier.

Note that the HTTP Bot API negates this identifier to signal that it is a chat, but the true value used by Telegram’s API is always strictly-positive.



Channel

Fields

id: i64

Bare channel identifier.

Note that the HTTP Bot API prefixes this identifier with -100 to signal that it is a channel, but the true value used by Telegram’s API is always strictly-positive.

auth: Option<PeerAuth>

Non-ambient authority bound to both the user itself and the session.

kind: Option<ChannelKind>

Channel kind, useful to determine what the possible permissions on it are.

Implementations

Source

impl PeerInfo

pub fn id(&self) -> PeerId

Returns the PeerId represented by this info.

The returned PeerId::kind() will never be PeerKind::UserSelf.

pub fn auth(&self) -> Option<PeerAuth>

Returns the PeerAuth stored in this info.