pub enum MessageBox {
Common {
pts: i32,
},
Secondary {
qts: i32,
},
Channel {
channel_id: i64,
pts: i32,
},
}Expand description
The message box and pts value that uniquely identifies the message-related update.
Variants
Common
Account-wide persistent timestamp.
This includes private conversations (one-to-one) and small group chats.
Secondary
Account-wide secondary persistent timestamp.
This includes only certain bot updates and secret one-to-one chats.
Channel
Channel-specific persistent timestamp.
This includes “megagroup”, “broadcast” and “supergroup” channels.
Implementations