UpdatesLike

Enum UpdatesLike 

pub enum UpdatesLike {
    Updates(Updates),
    ShortSentMessage {
        request: SendMessage,
        update: UpdateShortSentMessage,
    },
    AffectedMessages(AffectedMessages),
    InvitedUsers(InvitedUsers),
    ConnectionClosed,
}
Anything that should be treated like an update.

Telegram unfortunately also includes update state in types that are not part of the usual tl::enums::Updates.

Variants



Updates(Updates)

The usual variant, received passively from Telegram.



ShortSentMessage

Special-case for short-sent messages, where the request is also needed to construct a complete update.

Fields

request: SendMessage

The request that triggered the short update.

update: UpdateShortSentMessage

The incomplete update caused by the request.



AffectedMessages(AffectedMessages)

Special-case for requests that affect some messages.



InvitedUsers(InvitedUsers)

Special-case for requests that lead to users being invited.



ConnectionClosed

Indicates that the connection was closed and had to be recreated. This may mean that an update gap now exists and should be resolved.