pub enum PeerInfo {
User {
id: i64,
auth: Option<PeerAuth>,
bot: Option<bool>,
is_self: Option<bool>,
},
Chat {
id: i64,
},
Channel {
id: i64,
auth: Option<PeerAuth>,
kind: Option<ChannelKind>,
},
}Expand description
An exploded peer reference along with any known useful information about the peer.
Variants
User
Fields
Chat
Fields
Channel
Fields

id: i64Bare channel identifier.
Note that the HTTP Bot API prefixes this identifier with -100 to signal that it is a channel,
but the true value used by Telegram’s API is always strictly-positive.

kind: Option<ChannelKind>Channel kind, useful to determine what the possible permissions on it are.
Implementations